%bcond_without python

%ifarch %{java_arches}
%bcond_without java
%else
%bcond_with java
%endif

%global forgeurl https://gitlab.com/agrumery/aGrUM
Version:        1.8.3
%global tag %{version}
%forgemeta

Name:           agrum
Release:        %autorelease
Summary:        Structured Matrix Package (LBNL)
License:        LGPLv2
URL:            https://agrum.gitlab.io/
Source0:        %{forgesource}

# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch: %{ix86}

BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  ninja-build
BuildRequires:  swig
BuildRequires:  python3-devel
BuildRequires:  python3dist(matplotlib)
BuildRequires:  python3dist(matplotlib-inline)
BuildRequires:  python3dist(pydot)
BuildRequires:  python3dist(numpy)

%description
aGrUM is a C++ library designed to facilitate the development of applications
using graphical models such as Bayesian networks, influence diagrams, decision
trees, GAI networks or Markov decision processes.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{with python}
%package        python3
Summary:        Python 3 bindings for the %{name}
BuildRequires:  python3-devel
Requires:       %{name}%{?_isa} = %{version}-%{release}
Provides:       python3-%{name} = %{version}-%{release}

%description    python3
The python3-%{name} package contains Python 3 bindings for %{name}.
%endif

%if %{with java}
%package        java
Summary:        Java bindings for the %{name}
BuildRequires:  jpackage-utils
BuildRequires:  java-devel
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    java
The %{name}-java package contains Java bindings for %{name}.
%endif

%prep
%forgeautosetup -p1

%build
%if %{with java}
export JAVA_HOME=%{_jvmdir}/java
%endif

%cmake \
    -GNinja \
    -DCMAKE_BUILD_TYPE=Release \
    -DBUILD_PYTHON=ON \
%if %{with java}
    -DBUILD_JAVA=ON \
%endif
    -DCMAKE_SKIP_INSTALL_RPATH=ON \

%cmake_build

%install
%cmake_install

%check

%files
%license
%doc README.md
%{_libdir}/libagrum.so.1*

%files devel
%{_includedir}/agrum/
%{_libdir}/libagrum.so
%{_libdir}/pkgconfig/agrum.pc
%dir %{_libdir}/cmake/aGrUM
%{_libdir}/cmake/aGrUM/*.cmake

%if %{with python}
%files python3
%{python3_sitearch}/pyAgrum-%{version}-*.egg-info
%{python3_sitearch}/pyAgrum-%{version}.dist-info/
%{python3_sitearch}/pyAgrum/
%endif


%if %{with java}
%files java

%endif

%changelog
%autochangelog
